import { Coin } from "../../cosmos/base/v1beta1/coin";
import { BinaryReader, BinaryWriter } from "../../binary";
function createBaseParams() {
    return {
        distrEpochIdentifier: "",
        groupCreationFee: [],
        unrestrictedCreatorWhitelist: []
    };
}
export const Params = {
    typeUrl: "/osmosis.incentives.Params",
    encode(message, writer = BinaryWriter.create()) {
        if (message.distrEpochIdentifier !== "") {
            writer.uint32(10).string(message.distrEpochIdentifier);
        }
        for (const v of message.groupCreationFee) {
            Coin.encode(v, writer.uint32(18).fork()).ldelim();
        }
        for (const v of message.unrestrictedCreatorWhitelist) {
            writer.uint32(26).string(v);
        }
        return writer;
    },
    decode(input, length) {
        const reader = input instanceof BinaryReader ? input : new BinaryReader(input);
        let end = length === undefined ? reader.len : reader.pos + length;
        const message = createBaseParams();
        while (reader.pos < end) {
            const tag = reader.uint32();
            switch (tag >>> 3) {
                case 1:
                    message.distrEpochIdentifier = reader.string();
                    break;
                case 2:
                    message.groupCreationFee.push(Coin.decode(reader, reader.uint32()));
                    break;
                case 3:
                    message.unrestrictedCreatorWhitelist.push(reader.string());
                    break;
                default:
                    reader.skipType(tag & 7);
                    break;
            }
        }
        return message;
    },
    fromPartial(object) {
        const message = createBaseParams();
        message.distrEpochIdentifier = object.distrEpochIdentifier ?? "";
        message.groupCreationFee = object.groupCreationFee?.map(e => Coin.fromPartial(e)) || [];
        message.unrestrictedCreatorWhitelist = object.unrestrictedCreatorWhitelist?.map(e => e) || [];
        return message;
    },
    fromAmino(object) {
        const message = createBaseParams();
        if (object.distr_epoch_identifier !== undefined && object.distr_epoch_identifier !== null) {
            message.distrEpochIdentifier = object.distr_epoch_identifier;
        }
        message.groupCreationFee = object.group_creation_fee?.map(e => Coin.fromAmino(e)) || [];
        message.unrestrictedCreatorWhitelist = object.unrestricted_creator_whitelist?.map(e => e) || [];
        return message;
    },
    toAmino(message) {
        const obj = {};
        obj.distr_epoch_identifier = message.distrEpochIdentifier;
        if (message.groupCreationFee) {
            obj.group_creation_fee = message.groupCreationFee.map(e => e ? Coin.toAmino(e) : undefined);
        }
        else {
            obj.group_creation_fee = [];
        }
        if (message.unrestrictedCreatorWhitelist) {
            obj.unrestricted_creator_whitelist = message.unrestrictedCreatorWhitelist.map(e => e);
        }
        else {
            obj.unrestricted_creator_whitelist = [];
        }
        return obj;
    },
    fromAminoMsg(object) {
        return Params.fromAmino(object.value);
    },
    toAminoMsg(message) {
        return {
            type: "osmosis/incentives/params",
            value: Params.toAmino(message)
        };
    },
    fromProtoMsg(message) {
        return Params.decode(message.value);
    },
    toProto(message) {
        return Params.encode(message).finish();
    },
    toProtoMsg(message) {
        return {
            typeUrl: "/osmosis.incentives.Params",
            value: Params.encode(message).finish()
        };
    }
};
//# sourceMappingURL=params.js.map